@@ -1207,8 +1207,9 @@ void LogAuthThread::handleCoredump()
         }
 
         // 获取信号名称
-        int sigId = tmpList[7].toInt();
-        if ( sigId <= sigList.size()) {
+        bool isOk = false;
+        int sigId = tmpList[7].toInt(&isOk);
+        if (isOk && sigId >= 1 && sigId <= sigList.size()) {
             coredumpMsg.sig = sigList[sigId - 1];
         } else {
             coredumpMsg.sig = tmpList[7];
@@ -1249,6 +1250,7 @@ void LogAuthThread::handleCoredump()
     if (!m_canRun) {
         return;
     }
+
     //最后可能有余下不足600的数据
     if (coredumpList.count() >= 0) {
         emit coredumpData(m_threadCount, coredumpList);
