@@ -295,10 +295,6 @@ int main(int argc, char *argv[])
         //klu下不使用opengl 使用OpenGLES,因为opengl基于x11 现在全面换wayland了
         QCoreApplication::setAttribute(Qt::AA_UseOpenGLES);
         //klu下不使用opengl 使用OpenGLES,因为opengl基于x11 现在全面换wayland了,这个真正有效
-        qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell");
-        if (Utils::isWayland()) {
-            qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell");
-        }
         setenv("PULSE_PROP_media.role", "video", 1);
         QSurfaceFormat format;
         format.setRenderableType(QSurfaceFormat::OpenGLES);
